| Title: | A 'ggplot2' Theme and Scale Using 'Epiverse-TRACE' Visual Style |
|---|---|
| Description: | A 'ggplot2' theme and scale using 'Epiverse-TRACE' visual style, colour scheme, and visualisation guidelines. |
| Authors: | Hugo Gruson [aut, cre] (ORCID: <https://orcid.org/0000-0002-4094-1476>), The Epiverse-TRACE team [aut, cph] |
| Maintainer: | Hugo Gruson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-14 05:14:04 UTC |
| Source: | https://github.com/epiverse-trace/tracetheme |
Epiverse-TRACE default plotting dimensions for slides
slide_dimslide_dim
slide_dimA list with 2 elements:
A single numeric for the height of slide figures.
A single numeric for the width of slide figures.
A custom ggplot2 theme for Epiverse-TRACE packages and projects
theme_trace()theme_trace()
A ggplot2 theme object
library(ggplot2) showtext::showtext_auto() ggplot(mtcars, aes(wt, mpg)) + geom_point() + labs(title = "Fuel economy declines as weight increases") + theme_trace()library(ggplot2) showtext::showtext_auto() ggplot(mtcars, aes(wt, mpg)) + geom_point() + labs(title = "Fuel economy declines as weight increases") + theme_trace()
Epiverse-TRACE default plotting dimensions for vignettes
vignette_dimvignette_dim
vignette_dimA list with 2 elements:
A single numeric for the height of vignette figures.
A single numeric for the width of vignette figures.